#include "IoT-02_pinout.h"
#include "IoT-02_common.h"

#include "MHZ19.h"
#include <SoftwareSerial.h>                                // Remove if using HardwareSerial or Arduino package without SoftwareSerial support

#define RX_PIN 35 /*10 */                                         // Rx pin which the MHZ19 Tx pin is attached to
#define TX_PIN 19 /*11 */                                         // Tx pin which the MHZ19 Rx pin is attached to
#define BAUDRATE 9600                                      // Device to MH-Z19 Serial baudrate (should not be changed)

MHZ19 myMHZ19;                                             // Constructor for library

SoftwareSerial mySerial(RX_PIN, TX_PIN);

#include "IoT-02_oled.h"
SSD1306  display(0x3c, I2C_SDA, I2C_SCL);

const int Analog_channel_pin = 34; //ADC1_CH6
int ADC_VALUE = 0;
float voltage_value = 0;

unsigned long myMHZ19Timer = 0;

void setup() {
  Wire.begin(I2C_SDA, I2C_SCL);
  vSetupIO();
  vSetupScreen();
  Serial.begin(115200);
  mySerial.begin(BAUDRATE);
  myMHZ19.begin(mySerial);
  //pinMode(Analog_channel_pin, INPUT_PULLUP);
  myMHZ19.autoCalibration();
  Serial.println(__FILE__);
}

void loop() {
  int CO2;
  int8_t Temp;

  if (millis() - myMHZ19Timer >= 2000)  {
    Serial.println("-----------------");
    /*
      float adjustedADC = analogRead(A0);
      Serial.print("Analog raw: ");
      Serial.println(adjustedADC);

      adjustedADC = 6.4995 * adjustedADC - 590.53; // format; y=mx+c
      Serial.print("Analog CO2: ");
      Serial.println(adjustedADC);
    */
    CO2 = myMHZ19.getCO2();                             // Request CO2 (as ppm)

    Serial.print("CO2 (ppm): ");
    Serial.println(CO2);

    Temp = myMHZ19.getTemperature();                     // Request Temperature (as Celsius)
    Serial.print("Temperature (C): ");
    Serial.println(Temp);

    display.clear();
    display.setTextAlignment(TEXT_ALIGN_LEFT);
    display.setFont(ArialMT_Plain_16);
    display.drawString(0, 7, "CO2:");
    display.setFont(ArialMT_Plain_24);
    display.drawString(0, 25, String(CO2));
    display.setFont(ArialMT_Plain_16);
    display.drawString(0, 48, "ppm     T: "+String(Temp)+"ºC");
    display.display();

    myMHZ19Timer = millis();
  }
}
